## START: Set by rpmautospec
## (rpmautospec version 0.3.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           pipx
Version:        1.4.1
Release:        %autorelease
Summary:        Install and run Python applications in isolated environments

# SPDX
License:        MIT
URL:            https://pypa.github.io/pipx
# We need to use the GitHub source archive instead of the PyPI sdist in order
# to get the script to generate the man page.
%global forgeurl https://github.com/pypa/pipx
Source:         %{forgeurl}/archive/%{version}/pipx-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel

# noxfile.py: MAN_DEPENDENCIES
BuildRequires:  python3dist(argparse-manpage[setuptools])

BuildRequires:  /usr/bin/register-python-argcomplete

# The Markdown documentation is meant to be build with mkdocs. The HTML result
# is unsuitable for packaging due to various bundled and pre-minified
# JavaScript and CSS.  See https://bugzilla.redhat.com/show_bug.cgi?id=2006555
# for discussion of similar problems with Sphinx and Doxygen.
#
# We used to choose to install the Markdown documentation sources, as they are
# relatively readable without further processing but we’ve decided this isn’t
# really worthwile.
Obsoletes:      pipx-doc < 1.1.0-9

%description
pipx is a tool to help you install and run end-user applications written in
Python. It’s roughly similar to macOS’s brew, JavaScript’s npx, and Linux’s
apt.

It’s closely related to pip. In fact, it uses pip, but is focused on installing
and managing Python packages that can be run from the command line directly as
applications.


%prep
%autosetup


%generate_buildrequires
# We do not run the tests; but we add the runtime requirements as BR’s anyway
# so that the build will fail if some are not available in the distribution.
export SETUPTOOLS_SCM_PRETEND_VERSION='%{version}'
%pyproject_buildrequires


%build
export SETUPTOOLS_SCM_PRETEND_VERSION='%{version}'
%pyproject_wheel

# Generate shell completions. “pipx completions” says:
#
# Add the appropriate command to your shell's config file
# so that it is run on startup. You will likely have to restart
# or re-login for the autocompletion to start working.
#
# bash:
#     eval "$(register-python-argcomplete pipx)"
#
# zsh:
#     To activate completions for zsh you need to have
#     bashcompinit enabled in zsh:
#
#     autoload -U bashcompinit
#     bashcompinit
#
#     Afterwards you can enable completion for pipx:
#
#     eval "$(register-python-argcomplete pipx)"
#
# tcsh:
#     eval `register-python-argcomplete --shell tcsh pipx`
#
# fish:
#     # Not required to be in the config file, only run once
#     register-python-argcomplete --shell fish pipx >~/.config/fish/completions/pipx.fish
for sh in bash tcsh fish
do
  # We don’t need to be able to import pipx for this command to work.
  register-python-argcomplete --shell "${sh}" pipx > "pipx.${sh}"
done

# noxfile.py: build_man()
PYTHONPATH="${PWD}/src" %{python3} scripts/generate_man.py


%install
%pyproject_install
%pyproject_save_files -l pipx

install -p -m 0644 -D -t '%{buildroot}%{_mandir}/man1' pipx.1

install -p -m 0644 -D -t '%{buildroot}%{bash_completions_dir}' pipx.bash
install -p -m 0644 -D -t '%{buildroot}%{fish_completions_dir}' pipx.fish
# It seems that there is not a reasonable way to install tcsh completions
# system-wide, so we just make the completions file available for interested
# users.
install -p -m 0644 -D pipx.tcsh \
    '%{buildroot}%{_datadir}/pipx/pipx-completion.tcsh'
# Note that there are no “native” zsh completions, so we do not attempt to
# install anything. This could change if an actual zsh user recommends a
# different plan.


%check
# It’s just not practical to run the tests. For most of them, we need either
# (by default) a bundle of sample wheels from PyPI–which is arch-specific, as
# some of them have compiled extensions—or network access. Previously, we tried
# to disentangle the tests that did not require PyPI packages, but this has
# become onerous.
#
# Instead, we “smoke-test” the installation by running the command-line tool
# and confirming it can print its help output without crashing.

# Make sure the source copy of the package is not in the Python path.
mkdir -p empty
cd empty

PYTHONPATH=%{buildroot}%{python3_sitelib} \
    %{buildroot}%{_bindir}/pipx --help >/dev/null

# We separately do an import smoke test, although we must note that the package
# does not provide an API designed for external use.
%pyproject_check_import


%files -f %{pyproject_files}
%doc README.md

%{_bindir}/pipx
%{_mandir}/man1/pipx.1*

%{bash_completions_dir}/pipx.bash
%{fish_completions_dir}/pipx.fish

%{_datadir}/pipx/


%changelog
* Wed Jan 03 2024 Packit <hello@packit.dev> - 1.4.1-1
- [packit] 1.4.1 upstream release
- Resolves rhbz#2256702

* Mon Jan 01 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 1.4.0-1
- Update to 1.4.0 (close RHBZ#2256239)

* Fri Dec 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.3.3-2
- Assert that %%pyproject_files contains a license file

* Fri Dec 08 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.3.3-1
- Update to 1.3.3 (close RHBZ#2253591)

* Mon Dec 04 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.3.2-1
- Update to 1.3.2 (close RHBZ#2252688)

* Fri Nov 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.2.1-1
- Update to 1.2.1 (close RHBZ#2246047)

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Wed Jun 28 2023 Python Maint <python-maint@redhat.com> - 1.2.0-4
- Rebuilt for Python 3.12

* Mon Mar 13 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.2.0-1
- Update to 1.2.0 (close RHBZ#2177566)

* Fri Mar 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.0-12
- Depend on argparse-manpage with setuptools extra (fix RHBZ#2175193)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sun Jan 01 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.0-10
- With hatchling ≥1.12, pyproject_files handles LICENSE

* Wed Dec 21 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.0-9
- Drop the -doc subpackage; it is not really worthwhile

* Wed Dec 21 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.0-8
- Indicate dirs. in files list with trailing slashes

* Mon Nov 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.0-7
- Simplified packaging of completions
- Requires filesystem-3.18-1 or later, which owns fish completions dirs
- Requires redhat-rpm-config-228-1 or later for shell completion macros

* Thu Oct 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.0-6
- Confirm License is SPDX MIT

* Sun Sep 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.0-5
- Add correctly-packaged license file to the base package

* Sun Sep 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.0-4
- Use hatchling’s new “prepare_metadata_…” hook support for BR’s

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 1.1.0-2
- Rebuilt for Python 3.11

* Mon May 30 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.0-1
- Update to 1.1.0 (close RHBZ#2091341)

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Tue Jan 04 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 1.0.0-1
- Update to 1.0.0 (close RHBZ#2007950)

* Fri Dec 10 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.5-7
- Don’t bother setting PYTHONPATH for register-python-argcomplete

* Tue Dec 07 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.5-6
- Simplify PYTHONPATH for generating completions

* Tue Dec 07 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.5-5
- Generate completions without a temporary install

* Fri Oct 29 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.5-4
- Use the new %%%%pyproject_check_import macro

* Mon Oct 25 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.5-3
- Use %%%%python3 macro instead of %%%%__python3

* Tue Sep 28 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.5-2
- Update spec file comment about mkdocs

* Sun Sep 26 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.5-1
- Update to 0.16.5 (close RHBZ#2007950)

* Sun Sep 26 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.3-13
- Drop mkdocs support from the spec file completely

* Wed Sep 15 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.3-12
- Add a “smoke test” since it is impractical to run the upstream tests

* Wed Sep 15 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.3-11
- Update comment about shell completion directories

* Wed Sep 15 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.3-10
- Do not patch mkdocs.yml when we are not building documentation

* Sun Sep 12 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.3-9
- Let pyproject-rpm-macros handle the license file

* Sun Sep 12 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.3-8
- Drop BR on pyproject-rpm-macros, now implied by python3-devel

* Sun Sep 12 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.3-7
- Reduce macro indirection in the spec file

* Wed Aug 11 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.3-6
- Disable using mkdocs since it is orphaned

* Tue Jul 27 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.3-5
- Move %%generate_buildrequires after %%prep to make the spec file easier
  to follow

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.16.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 0.16.3-2
- Rebuilt for Python 3.10

* Sat May 29 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.3-1
- New version 0.16.3
- Drop support for running the tests; doing so has become impractical
- Re-number source files for downstream man pages

* Fri May 28 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.2.1-2
- Build documentation without the mkdocs-material theme
- Update URL and Source0 URL, which have moved

* Fri Apr 30 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.2.0-1
- New version 0.16.2.1

* Wed Apr 28 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.2.0-1
- New version 0.16.2.0
- Allow running network tests with a build conditional
- Add a complete set of man pages

* Tue Mar 30 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.1.0-4
- Use pyproject-rpm-macros for build and install, too
- Drop Fedora 32/33 workarounds since they lack the dependency versions
  required for the current version

* Thu Mar 25 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.1.0-3
- Improved source URL (better tarball name)

* Tue Mar 16 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.1.0-2
- Drop python3dist(setuptools) BR, redundant with %%pyproject_buildrequires

* Fri Feb 26 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.1.0-1
- New version 0.16.1.0

* Tue Feb 16 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16.0.0-1
- New version 0.16.0.0

* Sun Feb 14 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.15.6.0-1
- New version 0.15.6.0
- Use GitHub tarball instead of PyPI tarball
- License is now only “MIT” instead of “MIT and BSD”
- Drop obsolete python_provide macro; do not add py_provides, since the package
  is only to support the command-line tool and does not provide a public API
- Use pyproject-rpm-macros for generated BR’s
- Improve description
- Run those few tests that do not require network access
- Drop sed invocation, as there are no longer stray shebangs
- Build HTML documentation and install it in a new -doc subpackage
- Package shell completions

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.5.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Mon Oct  5 2020 Martin Jackson <mhjacks@swbell.net> - 0.15.5.1-3
- Add explicit dep on setuptools

* Sat Aug 29 2020 Martin Jackson <mhjacks@swbell.net> - 0.15.5.1-2
- Rebuilding.  Dep is OK on f33.

* Thu Aug 27 2020 Martin Jackson <mhjacks@swbell.net> - 0.15.5.1-1
- Update to upstream release 0.15.5.1

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.3.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 0.15.3.1-2
- Rebuilt for Python 3.9

* Mon May 18 2020 Martin Jackson <mhjacks@swbell.net> - 0.15.3.1-1
- Update to upstream release 0.15.3.1

* Tue Jan 21 2020 Martin Jackson <mhjacks@swbell.net> - 0.15.1.3-1
- Update to upstream release 0.15.1.3

* Sun Jan 12 2020 Martin Jackson <mhjacks@swbell.net> - 0.15.1.2-1
- Update to upstream release 0.15.1.2

* Sat Jan 04 2020 Martin Jackson <mhjacks@swbell.net> - 0.14.0.0-1
- Convert to pipx name

